Class: JayAPI::Elasticsearch::Cluster

Inherits:
Object
  • Object
show all
Extended by:
Forwardable
Defined in:
lib/jay_api/elasticsearch/cluster.rb

Overview

Represents the Elasticsearch cluster and provides access to cluster-level APIs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(transport_client) ⇒ Cluster

Returns a new instance of Cluster.

Parameters:

  • transport_client (Elasticsearch::Transport::Client)

    The transport client to use to make requests to the cluster.



20
21
22
# File 'lib/jay_api/elasticsearch/cluster.rb', line 20

def initialize(transport_client)
  @transport_client = transport_client
end

Instance Attribute Details

#transport_clientObject (readonly)

Returns the value of attribute transport_client.



16
17
18
# File 'lib/jay_api/elasticsearch/cluster.rb', line 16

def transport_client
  @transport_client
end